#
# spec file for package perl-Image-Sane
#
# Copyright (c) 2023 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


Name:           perl-Image-Sane
Version:        5
Release:        4.4
%define cpan_name Image-Sane
Summary:        Perl extension for the SANE (Scanner Access Now Easy)
License:        Artistic-1.0 OR GPL-1.0-or-later
Group:          Development/Libraries/Perl
URL:            https://metacpan.org/release/%{cpan_name}
Source0:        https://cpan.metacpan.org/authors/id/R/RA/RATCLIFFE/%{cpan_name}-%{version}.tar.gz
Source1:        cpanspec.yml
Patch0:         Image-Sane-5-Replace-deprecated-given-and-when-operators.patch
BuildRoot:      %{_tmppath}/%{name}-%{version}-build
BuildRequires:  perl
BuildRequires:  perl-macros
BuildRequires:  perl(Exception::Class)
BuildRequires:  perl(ExtUtils::Depends)
BuildRequires:  perl(ExtUtils::PkgConfig)
BuildRequires:  perl(Readonly)
BuildRequires:  perl(Test::Requires)
BuildRequires:  perl(Try::Tiny)
Requires:       perl(Exception::Class)
Requires:       perl(Readonly)
%{perl_requires}
# MANUAL BEGIN
BuildRequires:  ImageMagick
BuildRequires:  sane-backends
BuildRequires:  perl(Test::Pod)
BuildRequires:  pkgconfig(sane-backends)
# MANUAL END

%description
These Perl bindings for the SANE (Scanner Access Now Easy) Project allow
you to access SANE-compatible scanners in a Perlish and object-oriented
way, freeing you from the casting and memory management in C, yet remaining
very close in spirit to original API.

Find out more about SANE at http://www.sane-project.org.

%prep
%autosetup -p1 -n %{cpan_name}-%{version}
find . -type f ! -path "*/t/*" ! -name "*.pl" ! -name "*.sh" ! -path "*/bin/*" ! -path "*/script/*" ! -name "configure" -print0 | xargs -0 chmod 644

%build
perl Makefile.PL INSTALLDIRS=vendor OPTIMIZE="%{optflags}"
make %{?_smp_mflags}

%check
make test

%install
%perl_make_install
%perl_process_packlist
%perl_gen_filelist

%files -f %{name}.files
%defattr(-,root,root,755)
%doc Changes examples README

%changelog
* Mon Mar  4 2024 pgajdos@suse.com
- Use %%autosetup macro. Allows to eliminate the usage of deprecated
  %%patchN
* Tue Aug  8 2023 Dominique Leuenberger <dimstar@opensuse.org>
- Add Image-Sane-5-Replace-deprecated-given-and-when-operators.patch:
  Fix build using Perl 5.38.
* Thu Mar 19 2020 malcolmlewis@opensuse.org
- Add missing BuildRequires to complete all tests successfully.
* Tue Nov 19 2019 <timueller+perl@suse.de>
- updated to 5
  see /usr/share/doc/packages/perl-Image-Sane/Changes
  5     Fri, 15 Nov 2019 00:00 +0000
  - Fix tests broken by sane-backends 1.0.28. Closes RT 130933
    (t/81_scanimage-perl.t test fails with sane-backends-1.0.28)
* Fri Sep 13 2019 Tina Mueller <tina.mueller@suse.com>
- Add BuildRequires:  pkgconfig(sane-backends)
* Fri Sep 13 2019 <timueller+perl@suse.de>
- updated to 4
  see /usr/share/doc/packages/perl-Image-Sane/Changes
* Tue Aug  1 2017 malcolmlewis@opensuse.org
- Initial build.
